netapp_ontap.models.zapp_nvme_components API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.zapp_nvme_components`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ZappNvmeComponentsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ZappNvmeComponents object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `name GET POST PATCH`

    The name of the application component.

  `namespace_count GET POST PATCH`

    The number of namespaces in the component.

  `os_type GET POST PATCH`

    The name of the host OS running the application.

    Valid choices:

    - linux
    - vmware
    - windows
  `performance GET POST PATCH`

    The performance field of the zapp_nvme_components.

  `qos GET POST`

    The qos field of the zapp_nvme_components.

  `subsystem GET POST PATCH`

    The subsystem field of the zapp_nvme_components.

  `tiering GET POST PATCH`

    The tiering field of the zapp_nvme_components.

  `total_size GET POST PATCH`

    The total size of the component, spread across member namespaces. Usage: {<integer>[KB|MB|GB|TB|PB]}